@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 from app import Kola
 from blueprint import Blueprint
-from kola import safe_call, logger
\ No newline at end of file
+from kola import safe_call, safe_func, logger
\ No newline at end of file
