@@ -5,14 +5,13 @@ import functools
 
 from tornado.ioloop import IOLoop
 import kola
-from kola import safe_call
+from kola import safe_call, safe_func
 
 
 class Blueprint(kola.Blueprint):
 
     def __init__(self, name):
         super(Blueprint, self).__init__(name)
-        self.repeat_app_timer_func_list = []
 
     def repeat_app_timer(self, interval):
         """
@@ -28,6 +27,6 @@ class Blueprint(kola.Blueprint):
 
                 return result
 
-            self.repeat_app_timer_func_list.append(func_wrapper)
+            self.events.repeat_app_timer += safe_func(func_wrapper)
             return func_wrapper
         return inner_repeat_timer
