@@ -2,7 +2,7 @@
 
 from tornado import ioloop
 import time
-from kola.utils import safe_call
+from kola import safe_call
 
 
 class Later(object):
